================================
Applied Guides
================================

Full guides through applied examples

The following tutorials can be found in `zfit tutorials as Jupyter Notebooks. <https://github.com/zfit/zfit-tutorials>`_

.. toctree::
    :maxdepth: 1

    ../../../_tmp/zfit-tutorials/guides/constraints_simultaneous_fit_discovery_splot.ipynb
    ../../../_tmp/zfit-tutorials/guides/custom_models.ipynb
